#version 120

uniform sampler2D texture0;

uniform vec2 worldSize;
uniform vec2 worldPosition;
uniform float worldRadius;

varying vec2 v_texcoord;
varying vec4 v_color;
varying vec2 v_mask;

float roundedBoxSDF(vec2 CenterPosition, vec2 Size, float Radius) {
    return length(max(abs(CenterPosition)-Size+Radius,0.0))-Radius;
}

void main() {
	vec4 color = texture2D(texture0, v_texcoord.xy) * v_color * v_mask.x + v_color * v_mask.y;

    float edgeSoftness  = 1.0f;
    float radius = worldRadius;
    vec2 fc = gl_FragCoord.xy;
    vec2 location = worldPosition;
    vec2 size = worldSize;
    float distance = roundedBoxSDF(fc - location - (size/2.0f), size / 2.0f, radius);
    float smoothedAlpha =  1.0f - smoothstep(0.0f, edgeSoftness * 2.0f, distance);
    vec4 finalColor = mix(vec4(1.0f, 1.0f, 1.0f, 0.0f), vec4(color.r, color.g, color.b, color.a * smoothedAlpha), smoothedAlpha);

    finalColor.r *= finalColor.a;
	finalColor.g *= finalColor.a;
	finalColor.b *= finalColor.a;

	gl_FragColor = finalColor;
}
